import React, { useRef, useState } from 'react';
import { updateLink, queryLinkAttrs } from '@bangle.dev/core/components/link';
import * as Icons from './Icons';
import { useEditorViewContext } from '@bangle.dev/react';
import { MenuButton } from './Icon';
import { MenuGroup } from './MenuGroup';
export function LinkSubMenu({ getIsTop = () => true }) {
    const view = useEditorViewContext();
    const result = queryLinkAttrs()(view.state);
    const originalHref = (result && result.href) || '';
    return (React.createElement(LinkMenu, { key: originalHref, originalHref: originalHref, view: view, getIsTop: getIsTop }));
}
function LinkMenu({ getIsTop, view, originalHref = '', }) {
    const [href, setHref] = useState(originalHref);
    const inputRef = useRef(null);
    const handleSubmit = () => {
        updateLink(href)(view.state, view.dispatch);
        view.focus();
    };
    return (React.createElement("span", { className: "bangle-link-menu" },
        React.createElement("input", { value: href, ref: inputRef, onKeyDown: (e) => {
                if (e.key === 'Enter') {
                    e.preventDefault();
                    handleSubmit();
                    view.focus();
                    return;
                }
                const isTop = getIsTop();
                if (isTop && e.key === 'ArrowDown') {
                    e.preventDefault();
                    view.focus();
                    return;
                }
                if (!isTop && e.key === 'ArrowUp') {
                    e.preventDefault();
                    view.focus();
                    return;
                }
                if (e.key === 'Escape') {
                    e.preventDefault();
                    view.focus();
                    return;
                }
            }, onChange: (e) => {
                setHref(e.target.value);
                e.preventDefault();
            } }),
        React.createElement(MenuGroup, null,
            React.createElement(MenuButton, { hint: "Visit", onMouseDown: (e) => {
                    e.preventDefault();
                    window.open(href, '_blank');
                } },
                React.createElement(Icons.ExternalIcon, null))),
        href === originalHref ? (React.createElement(MenuButton, { hint: "Clear", onMouseDown: (e) => {
                e.preventDefault();
                updateLink()(view.state, view.dispatch);
                view.focus();
            } },
            React.createElement(Icons.CloseIcon, null))) : (React.createElement(MenuButton, { hint: "Save", onMouseDown: (e) => {
                e.preventDefault();
                handleSubmit();
                view.focus();
            } },
            React.createElement(Icons.DoneIcon, null)))));
}
